/*
 * Copyright (C) 2024, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: zhouyong <zhouyong01@kylinos.cn>
 *
 */

import QtQuick 2.15
import QtQuick.Controls 2.15
import org.ukui.shortcut.audio 1.0
import org.ukui.audio.common 1.0
import org.ukui.audio.sinkcontrol 1.0
import org.ukui.audio.sourcecontrol 1.0

Item {
    id: qmlAudioAreaItem
    anchors.fill: parent
    anchors.top: parent.top
    anchors.topMargin: 56

    Column {
        anchors.fill: parent

        VolumeDelegate {
            id: volumeDelegate
            volumeDelegateHeight: 48

            onVolumeDelegateBtnClick: {
                console.log("AudioArea.qml onVolumeDelegateBtnClick")
                UKUIAudioControl.startTask(Common.TaskID_SetSinkMute, ""
                                              , volumeDelegateBtnHighLighted)
            }

            onMoved: {
                console.log("AudioArea.qml onMoved value:",value)
                UKUIAudioControl.startTask(Common.TaskID_SetSinkVolume, "", value)
            }
        }

        Rectangle {
            id: lineTop
            width: parent.width
            height: 1
            color: "#e0e0e0"
        }

        AudioListArea {
            id: audioListArea

        }

        Rectangle {
            id: lineBottom
            width: parent.width
            height: 1
            color: "#e0e0e0"
        }

        Rectangle {
            id: moreAudioSettings
            width: parent.width
            height: 56
            color: "#00000000"

            Text {
                id: moreAudioSettingsText
                height: 22
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 24
                text: qsTr("更多声音设置")
                font.pixelSize: 14

                MouseArea {
                    anchors.fill: parent
                    hoverEnabled: true
                    onEntered: moreAudioSettingsText.color = "#3676F5"
                    onExited: moreAudioSettingsText.color = "#000000"

                    onClicked: {
                        console.log("AudioArea.qml onClicked moreAudioSettings")
                        UKUIAudioControl.startTask(Common.TaskID_JumpControlPanelAudio)
                    }
                }
            }
        }
    }

    Component.onCompleted: {
        console.log("AudioArea.qml onCompleted")
        UKUIAudioControl.startTask(Common.TaskID_GetSinkVolume)
        UKUIAudioControl.startTask(Common.TaskID_GetSinkMute)
    }

    Connections {
        target: UKUIAudioSinkControl

        function onSinkVolumeValueChanged(sinkVolumeValue) {
            console.log("AudioArea.qml onSinkVolumeValueChanged sinkVolumeValue:",sinkVolumeValue)
            volumeDelegate.volumeValue = sinkVolumeValue
        }

        function onSinkMuteStatusChanged(sinkMuteStatus) {
            console.log("AudioArea.qml onSinkMuteStatusChanged sinkMuteStatus:",sinkMuteStatus)
            volumeDelegate.volumeDelegateBtnHighLighted = !sinkMuteStatus
            if (sinkMuteStatus) {
                volumeDelegate.volumeDelegateBtnFlat = !sinkMuteStatus
            } else {
                volumeDelegate.volumeDelegateBtnFlat = sinkMuteStatus
            }
        }

        function onSinkVolumeStatusIconChanged(sinkVolumeStatusIcon) {
            console.log("AudioArea.qml onSinkVolumeStatusIconChanged sinkVolumeStatusIcon:",sinkVolumeStatusIcon)
            volumeDelegate.volumeDelegateBtnSource = sinkVolumeStatusIcon
        }

        function onSinkDeviceChanged(portName, cardName) {
            console.log("AudioArea.qml onSinkDeviceChanged:",portName,cardName)
            UKUIAudioSinkControl.updateSinkDefaultDevice(portName, cardName)
            UKUIAudioControl.startTask(Common.TaskID_GetSinkVolume)
        }

        function onSinkDeviceAdjust() {
            console.log("AudioArea.qml onSinkDeviceAdjust")
            UKUIAudioControl.startTask(Common.TaskID_GetSinkAvailablePortList)
        }
    }

    Connections {
        target: UKUIAudioControl

        function onTaskCompleted(taskID, retValue) {
            console.log("AudioArea.qml onTaskCompleted taskID:",taskID)
            if (taskID === Common.TaskID_Init) {

            } else if (taskID === Common.TaskID_GetSinkVolume) {
                UKUIAudioSinkControl.updateSinkVolume(retValue)
            } else if (taskID === Common.TaskID_SetSinkVolume) {

            } else if (taskID === Common.TaskID_GetSinkMute) {
                UKUIAudioSinkControl.updateSinkMute(retValue)
            } else if (taskID === Common.TaskID_SetSinkMute) {

            } else if (taskID === Common.TaskID_SetSinkInputVolume) {

            } else if (taskID === Common.TaskID_GetSourceVolume) {

            } else if (taskID === Common.TaskID_SetSourceVolume) {

            } else if (taskID === Common.TaskID_GetSinkAvailablePortList) {
                UKUIAudioSinkControl.updateSinkAvailablePortList(retValue)
                UKUIAudioControl.startTask(Common.TaskID_GetSinkDefaultDevice)
            } else if (taskID === Common.TaskID_GetSourceAvailablePortList) {

            } else if (taskID === Common.TaskID_GetSinkInputList) {
                UKUIAudioSinkControl.updateSinkInputList(retValue)
            } else if (taskID === Common.TaskID_GetSourceInputList) {

            } else if (taskID === Common.TaskID_GetSinkDefaultDevice) {
                UKUIAudioSinkControl.updateSinkDefaultDevice(retValue)
            } else if (taskID === Common.TaskID_SetSinkDefaultDevice) {

            } else if (taskID === Common.TaskID_GetSourceDefaultDevice) {

            } else if (taskID === Common.TaskID_SetSourceDefaultDevice) {

            } else if (taskID === Common.TaskID_JumpControlPanelAudio) {

            }
        }

        function onTaskError(taskID) {
            console.log("AudioArea.qml onTaskError taskID:",taskID)
            if (taskID === Common.TaskID_Init) {

            } else if (taskID === Common.TaskID_GetSinkVolume) {

            } else if (taskID === Common.TaskID_SetSinkVolume) {

            } else if (taskID === Common.TaskID_GetSourceVolume) {

            } else if (taskID === Common.TaskID_SetSourceVolume) {

            } else if (taskID === Common.TaskID_GetSinkAvailablePortList) {

            } else if (taskID === Common.TaskID_GetSourceAvailablePortList) {

            } else if (taskID === Common.TaskID_GetSinkInputList) {

            } else if (taskID === Common.TaskID_GetSourceInputList) {

            } else if (taskID === Common.TaskID_GetSinkDefaultDevice) {

            } else if (taskID === Common.TaskID_SetSinkDefaultDevice) {

            } else if (taskID === Common.TaskID_GetSourceDefaultDevice) {

            } else if (taskID === Common.TaskID_SetSourceDefaultDevice) {

            } else if (taskID === Common.TaskID_JumpControlPanelAudio) {

            }
        }
    }
}


