import QtQuick 2.15
import QtQuick.Controls 2.15
import org.ukui.shortcut.audio 1.0
import org.ukui.audio.common 1.0
import org.ukui.audio.sinkcontrol 1.0
import org.ukui.audio.sinkmodel 1.0

Item {
    id: listViewItem
    width: parent.width
    height: 305

    ListView {
        id: listView
        anchors.fill: parent
        model: UKUIAudioSinkModel
        clip: true

        ScrollBar.vertical: ScrollBar {
            id: verticalScrollBar
            policy: listView.contentHeight > listView.height ? ScrollBar.AlwaysOn : ScrollBar.AlwaysOff
        }

        delegate: Loader {
            width: parent.width

            property var modelData: model

            sourceComponent: {
//                console.log("AudioListArea.qml Item type:", model.itemType, model.title, model.portName, modelData.portIcon, modelData.cardDesc, modelData.isActivePort
//                            , model.streamIconName, model.streamVolume)
                switch(model.itemType) {
                case UKUIAudioSinkModel.HeaderOutput:
                case UKUIAudioSinkModel.HeaderAppVolume:
                    return headerComponent
                case UKUIAudioSinkModel.EmptyDeviceItem:
                case UKUIAudioSinkModel.EmptyStreamItem:
                    return emptyDelegateComponent
                case UKUIAudioSinkModel.DeviceItem:
                    return deviceComponent
                case UKUIAudioSinkModel.StreamItem:
                    return appVolumeComponent
                }
            }
        }

        // 标题组件
        Component {
            id: headerComponent
            HeaderDelegate {
                headerDelegateTextStr: modelData.title
//                headerDelegateBtnVisible: modelData.itemType === UKUIAudioSinkModel.HeaderAppVolume ? true : false
//                headerDelegateBtnEnabled: modelData.itemType === UKUIAudioSinkModel.HeaderAppVolume ? true : false
//                headerDelegateBtnSource: modelData.itemType === UKUIAudioSinkModel.HeaderAppVolume ? "application-system-symbolic" : ""
                headerDelegateBtnFlat: true
                headerDelegateBtnHighLighted: false

                onHeaderDelegateBtnClick: {
                    console.log("AudioListArea.qml onHeaderDelegateBtnClick")
//                    UKUIAudioControl.startTask(Common.TaskID_JumpControlPanelAudio)
                }
            }
        }

        // 设备项组件
        Component {
            id: deviceComponent
            DeviceDelegate {
                deviceDelegatePortTextStr: modelData.portLabel
                deviceDelegateBtnSource: modelData.portIcon
                deviceDelegateDesTextStr: qsTr("( ") + modelData.cardDesc + qsTr(" )")
                deviceDelegateBtnHighLighted: modelData.isActivePort

                MouseArea {
                    anchors.fill: parent

                    onClicked: {
                        console.log("AudioListArea.qml onClicked portName cardName portIcon:", modelData.portName, modelData.portIcon, modelData.cardName)
                        UKUIAudioControl.startTask(Common.TaskID_SetSinkDefaultDevice, modelData.portName, modelData.cardName)
                    }
                }
            }
        }

        // 应用音量项组件
        Component {
            id: appVolumeComponent
            VolumeDelegate {
                volumeValue: modelData.streamVolume
                volumeDelegateBtnSource: modelData.streamIconName
                volumeDelegateBtnHighLighted: false
                volumeDelegateBtnFlat: true

                onMoved: {
                    console.log("AudioListArea.qml onMoved value:",value)
                    UKUIAudioControl.startTask(Common.TaskID_SetSinkInputVolume, modelData.streamName, value)
                }
            }
        }

        // 空项组件
        Component {
            id: emptyDelegateComponent
            EmptyDelegate {
                emptyDelegateTextStr: modelData.title
            }
        }

        Component.onDestruction: {
            console.log("AudioListArea.qml ListView onDestruction")

        }
    }

    Component.onCompleted: {
        console.log("AudioListArea.qml onCompleted")
        UKUIAudioControl.startTask(Common.TaskID_GetSinkAvailablePortList)
        UKUIAudioControl.startTask(Common.TaskID_GetSinkInputList)
    }
}
